@@ -109,6 +109,13 @@ process_initial_entry (const char *line)
     return;
   }    
 
+  if (!current_category) {
+    /* The docs are appearing before the first category.  Ignore
+       them. */
+    fprintf (stderr, "Error: Documents outwith categories.  Ignoring\n");
+    return;
+  }
+
   tmp++;
   end_name = strchr(tmp, ':');
   if (!end_name) {
@@ -507,7 +514,7 @@ process_info_dir (const char *dir)
   }
   current_entry = NULL;
   free (line);
-  close(fp);
+  fclose(fp);
   free (filename);
 }
 
@@ -668,8 +675,10 @@ rrn_info_find_from_uri (char *uri, char *section)
     l = l->next;
   }
   
-  return best_result->reg;
+  if (best_result)
+     return best_result->reg;
 
+  return NULL;
 }
 
 void 
