@@ -532,7 +532,8 @@ omf_process_category (char *omf_cat)
       if (!next || *next == 0 || !strcmp (next, "Other") ||
 	  !strncmp (next, "Accessories", 11)) {
 	result = strdup ("Utility");
-      } else if (!strncmp (next, "Amusement", 9)) {
+      } else if (!strncmp (next, "Amusement", 9) ||
+		 !strncmp (next, "Games", 5)) {
 	result = strdup ("Game");
       } else if (!strncmp (next, "Clock", 5)) {
 	result = strdup ("Clock");
@@ -542,7 +543,6 @@ omf_process_category (char *omf_cat)
 	result = strdup ("AudioVideo");
       } else if (!strncmp (next, "Network", 7) || 
 		 !strncmp (next, "Internet", 8)) {
-	printf ("Got a network...\n");
 	result = strdup ("Network");
       } else if (!strncmp (next, "Utility", 7)) {
 	result = strdup ("Utility");
