@@ -25,6 +25,8 @@
 #include <string.h>
 #include <ctype.h>
 
+/* TODO: Figure out why this is required here */
+#define I_KNOW_RARIAN_0_8_IS_UNSTABLE
 #include "rarian-reg-full.h"
 #include "rarian-reg-utils.h"
 #include "rarian-utils.h"
@@ -59,6 +61,8 @@ rrn_reg_new_full ()
     reg->heritage    = NULL;
     reg->lang = NULL;
     reg->children = NULL;
+    
+    return reg;
 }
 
 RrnRegFull *
@@ -140,6 +144,7 @@ rrn_reg_parse_file_full (char *filename)
 			fprintf (stdout, "WARNING: Don't know how to handle line: %s\n", buf);
 		}
     }
+    fclose (file);
     free (buf);
 	if (sect) {
 		if (rrn_reg_add_sect_full (reg, sect) == 1) {
@@ -299,36 +304,40 @@ process_categories_full (char *cat_string)
 static void
 process_pair_full (RrnRegFull *reg, char *key, char *value)
 {
-    char *lang = NULL;
+  char *lang = NULL;
 
-    lang = find_language (key);
+  lang = find_language (key);
 
-    if (!strncmp (key, "Name", 4) || !strncmp (key, "name", 4)) {
-        reg->name = rrn_full_add_field (reg->name, value, lang);
-    } else if (!strncmp (key, "Comment", 7) || !strncmp (key, "comment", 7)) {
-        reg->comment = rrn_full_add_field (reg->comment, value, lang);
-    } else if (!strncmp (key, "DocPath", 7) || !strncmp (key, "docpath", 7)) {
-        reg->uri = rrn_full_add_field (reg->uri, value, lang);
-    } else if (!strcmp (key, "DocIdentifier") || !strcmp (key, "docidentifier")) {
-        reg->identifier = strdup (value);
-    } else if (!strcmp (key, "DocType") || !strcmp (key, "doctype")) {
-        reg->type = strdup (value);
-	} else if (!strcmp (key, "Categories") || !strcmp (key, "categories")) {
-		reg->categories = process_categories_full (value);
-	} else if (!strcmp (key, "DocWeight") || !strcmp (key, "docweight")) {
-		reg->weight = atoi (value);
-	} else if (!strcmp (key, "DocHeritage") || !strcmp (key, "docheritage")) {
-		reg->heritage = strdup (value);
-	} else if (!strcmp (key, "DocLang") || !strcmp (key, "doclang")) {
-		if (!reg->lang) {
-			reg->lang = strdup (value);
-		}
-	} else if (!strcmp (key, "Icon") || !strcmp (key, "icon")) {
-		reg->icon = strdup (value);
-    } else {
-        fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  if (!strncmp (key, "Name", 4)) {
+    reg->name = rrn_full_add_field (reg->name, value, lang);
+  } else if (!strncmp (key, "Comment", 7)) {
+    reg->comment = rrn_full_add_field (reg->comment, value, lang);
+  } else if (!strncmp (key, "DocPath", 7)) {
+    reg->uri = rrn_full_add_field (reg->uri, value, lang);
+  } else if (!strcmp (key, "DocIdentifier")) {
+    reg->identifier = strdup (value);
+  } else if (!strcmp (key, "DocType")) {
+    reg->type = strdup (value);
+  } else if (!strcmp (key, "Categories")) {
+    reg->categories = process_categories_full (value);
+  } else if (!strcmp (key, "DocWeight")) {
+    reg->weight = atoi (value);
+  } else if (!strcmp (key, "DocHeritage")) {
+    reg->heritage = strdup (value);
+  } else if (!strcmp (key, "NoDisplay")) {
+    reg->hidden = TRUE;
+  } else if (!strcmp (key, "DocDefaultSection")) {
+    reg->default_section = strdup (value);
+  } else if (!strcmp (key, "DocLang")) {
+    if (!reg->lang) {
+      reg->lang = strdup (value);
     }
-    return;
+  } else if (!strcmp (key, "Icon")){
+    reg->icon = strdup (value);
+  } else {
+    fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  }
+  return;
 }
 
 void
@@ -554,6 +563,7 @@ rrn_sect_parse_file_full (char *filename)
 			fprintf (stderr, "WARNING: Don't know how to handle line: %s\n", buf);
 		}
     }
+    fclose (file);
     free (buf);
 
 	if (sect) {
