@@ -19,13 +19,16 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+/* This file is the main header for the rarian library.
+ * If you include this file, you should get everything you
+ * need to work with rarian.
+ */
+
 #ifndef __RARIAN_H
 #define __RARIAN_H
 
-#include <rarian-reg-utils.h>
-
-#ifdef __cplusplus
-extern "C" {
+#ifndef I_KNOW_RARIAN_0_8_IS_UNSTABLE
+#error Rarian is unstable.  To use it, you must acknowledge that
 #endif
 
 #ifndef FALSE
@@ -33,24 +36,10 @@ extern "C" {
 #define TRUE !FALSE
 #endif
 
-  typedef int (* RrnForeachFunc) (void * reg, void *data);
+#include <rarian-reg-utils.h>
+#include <rarian-main.h>
+#include <rarian-man.h>
+#include <rarian-info.h>
 
-  void rrn_set_language (char *lang_code);
-
-  void rrn_for_each (RrnForeachFunc funct, void * user_data);
-
-  void rrn_for_each_in_category (RrnForeachFunc funct, char * category,
-				   void *user_data);
-  RrnReg * rrn_find_entry_from_uri (char *uri);
-
-  RrnReg * rrn_find_from_name (char *name);
-
-  RrnReg * rrn_find_from_ghelp (char *ghelp);
-  
-  void rrn_shutdown ();
-
-#ifdef __cplusplus
-}
-#endif
 
 #endif /*__RARIAN_H */
