@@ -20,8 +20,8 @@
  * Boston, MA  02110-1301  USA
  */
 
+#define I_KNOW_RARIAN_0_8_IS_UNSTABLE
 #include <rarian.h>
-#include <rarian-reg-utils.h>
 #include <rarian-utils.h>
 #include <tinyxml.h>
 #include <sys/stat.h>
@@ -166,6 +166,11 @@ find_dump_name ()
   unsigned int lasttime = 0;
   int init = 1;
 
+  if (!user) {
+    /* if USERNAME isn't set, we use the "default" username: UNKNOWN */
+    user = strdup ("UNKNOWN");
+  }
+
   basepath = (char *) malloc (sizeof(char) * (strlen(user) + 18 /*/tmp/scrollkeeper.*/ + 1));
   sprintf (basepath, "/tmp/scrollkeeper-%s", user);
   mkdir(basepath, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
